Improve this Doc

# Error: $interpolate:reqendbrace
Unterminated message for plural/select value

    The plural/select choice “{0}” message starting at line {1}, column {2} does not have an ending closing brace. Text “{3}”

## Description

The plural or select message for a value or keyword choice has no matching end brace to mark the end of the message.

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat